@@ -926,6 +926,8 @@ namespace Commands {
                     Manager::imagePngToFile(p->imageCacheQueue.back().second, out_path.string());
                     Term::clearLine(out);
                     out << "\rSaved to " << out_path << std::endl;
+                } else {
+                    out << termcolor::red << "Error:" << termcolor::reset << " no image in image queue " << std::endl;
                 }
             } else if (out_path.extension() == ".pdf" || out_path.extension() == ".svg") {
                 std::string format_str = (out_path.extension() == ".pdf") ? "pdf" : "svg";
@@ -944,12 +946,20 @@ namespace Commands {
                     cl.resetDrawState();
                 }
                 if (format_str == "pdf") {
+                    if (p->mode == Manager::TILED) {
+                        out << termcolor::red << "Error:" << termcolor::reset << " file type not supported for tiled images, only .png is" << out_path.extension() << std::endl;
+                        return Err::OPTION_NOT_SUPPORTED;
+                    }
                     auto pdfDocument = SkPDF::MakeDocument(&buffer);
                     SkCanvas *pageCanvas = pdfDocument->beginPage(p->fb_width, p->fb_height);
                     p->runDrawOnCanvas(pageCanvas);
                     pdfDocument->close();
                     buffer.writeToStream(&out_stream);
                 } else {
+                    if (p->mode == Manager::TILED) {
+                        out << termcolor::red << "Error:" << termcolor::reset << " file type not supported for tiled images, only .png is" << out_path.extension() << std::endl;
+                        return Err::OPTION_NOT_SUPPORTED;
+                    }
                     SkPictureRecorder recorder;
                     SkCanvas* canvas = recorder.beginRecording(SkRect::MakeWH(p->fb_width, p->fb_height));
                     p->runDrawOnCanvas(canvas);
@@ -957,12 +967,11 @@ namespace Commands {
                     std::unique_ptr<SkCanvas> svgCanvas = SkSVGCanvas::Make(SkRect::MakeWH(p->fb_width, p->fb_height), &out_stream);
                     if (svgCanvas) {
                         picture->playback(svgCanvas.get());
-//                        svgCanvas->flush();
                     };
                 }
                 out << "\rSaved to " << out_path << std::endl;
             } else {
-                out << termcolor::red << "Error:" << termcolor::reset << " extension not supported " << out_path.extension() << std::endl;
+                out << termcolor::red << "Error:" << termcolor::reset << " file type not supported (Need one of .png|.pdf|.svg) " << out_path.extension() << std::endl;
                 return Err::OPTION_NOT_SUPPORTED;
             }
         }
@@ -1342,6 +1351,26 @@ namespace Commands {
         return Err::NONE;
     }
 
+    Err search_for_feature(Plot* p, std::string& command, Utils::Region& rgn) {
+        p->redraw = true;
+        if (p->tracks.empty()) {
+            return Err::NONE;
+        }
+        bool res = HGW::searchTracks(p->tracks, command, rgn);
+        if (!res) {
+            return Err::FEATURE_NOT_IN_TRACKS;
+        }
+        if (p->mode != Manager::Show::SINGLE) { p->mode = Manager::Show::SINGLE; }
+        if (p->regions.empty()) {
+            p->regions.push_back(rgn);
+            p->fetchRefSeq(p->regions.back());
+        } else if (p->regionSelection < (int)p->regions.size()) {
+            p->regions[p->regionSelection] = rgn;
+            p->fetchRefSeq(p->regions[p->regionSelection]);
+        }
+        return Err::NONE;
+    }
+
     Err infer_region_or_feature(Plot* p, std::string& command, std::vector<std::string> parts, std::ostream& out) {
         Utils::Region rgn;
         Err reason = Err::NONE;
@@ -1349,28 +1378,31 @@ namespace Commands {
             rgn = Utils::parseRegion(command);
         } catch (...) {
             p->redraw = true;
-            return Err::BAD_REGION;
+            reason = Err::BAD_REGION;
+//            return Err::BAD_REGION;
         }
         if (reason == Err::NONE) {
             int res = faidx_has_seq(p->fai, rgn.chrom.c_str());
             if (res <= 0) {
-                p->redraw = true;
-                int num_sequences = faidx_nseq(p->fai);
-                out << "Error: Command not understood\n";
-                out << "Chromosome names in the fasta index:" << std::endl;
-                for (int i = 0; i < num_sequences; ++i) {
-                    const char* seq_name = faidx_iseq(p->fai, i);
-                    out << seq_name;
-                    if (i < num_sequences - 1) {
-                        out << ", ";
-                    }
-                    if (i > 25) {
-                        out << " ... ";
-                        break;
+                reason = search_for_feature(p, command, rgn);
+                if (reason == Err::FEATURE_NOT_IN_TRACKS) {
+                    p->redraw = true;
+                    int num_sequences = faidx_nseq(p->fai);
+                    out << "Chromosome names in the fasta index:" << std::endl;
+                    for (int i = 0; i < num_sequences; ++i) {
+                        const char* seq_name = faidx_iseq(p->fai, i);
+                        out << seq_name;
+                        if (i < num_sequences - 1) {
+                            out << ", ";
+                        }
+                        if (i > 25) {
+                            out << " ... ";
+                            break;
+                        }
                     }
+                    out << std::endl << std::endl;
+                    return Err::OPTION_NOT_UNDERSTOOD;
                 }
-                out << std::endl << std::endl;
-                return Err::OPTION_NOT_UNDERSTOOD;
             }
             if (p->mode != Manager::Show::SINGLE) { p->mode = Manager::Show::SINGLE; }
             if (p->regions.empty()) {
@@ -1391,24 +1423,7 @@ namespace Commands {
                 p->regions[p->regionSelection].chromLen = faidx_seq_len(p->fai, p->regions[p->regionSelection].chrom.c_str());
             }
         } else {  // search all tracks for matching name, slow but ok for small tracks
-            if (!p->tracks.empty()) {
-                bool res = HGW::searchTracks(p->tracks, command, rgn);
-                if (res) {
-                    if (p->mode != Manager::Show::SINGLE) { p->mode = Manager::Show::SINGLE; }
-                    if (p->regions.empty()) {
-                        p->regions.push_back(rgn);
-                        p->fetchRefSeq(p->regions.back());
-                    } else {
-                        if (p->regionSelection < (int)p->regions.size()) {
-                            p->regions[p->regionSelection] = rgn;
-                            p->fetchRefSeq(p->regions[p->regionSelection]);
-                        }
-                    }
-                } else {
-                    p->redraw = true;
-                    reason = Err::SILENT;
-                }
-            }
+            reason = search_for_feature(p, command, rgn);
         }
         if (reason == Err::NONE && p->frameId >= 0) {
             p->processed = false;
