@@ -24,6 +24,11 @@
 #include "include/core/SkPictureRecorder.h"
 #include "include/core/SkPicture.h"
 #include "include/svg/SkSVGCanvas.h"
+#if !defined(OLD_SKIA) || OLD_SKIA == 0
+    #include "include/gpu/ganesh/gl/GrGLAssembleInterface.h"
+#else
+    #include "include/gpu/gl/GrGLAssembleInterface.h"
+#endif
 
 #include "ankerl_unordered_dense.h"
 #include "drawing.h"
@@ -168,7 +173,7 @@ namespace Manager {
     }
 
     int GwPlot::makeRasterSurface() {
-#ifndef OLD_SKIA
+#if !defined(OLD_SKIA) || OLD_SKIA == 0
         SkImageInfo imageInfo = SkImageInfo::MakeN32Premul(opts.dimensions.x * monitorScale,
                                                            opts.dimensions.y * monitorScale);
         size_t rowBytes = imageInfo.minRowBytes();
@@ -859,7 +864,21 @@ namespace Manager {
 
                 sContext->abandonContext();
                 sk_sp<const GrGLInterface> interface = GrGLMakeNativeInterface();
-#ifndef OLD_SKIA
+
+                if (!interface) {
+                    interface = GrGLMakeAssembledInterface(
+                            nullptr,
+                            [](void*, const char* name) -> GrGLFuncPtr {
+                                return (GrGLFuncPtr)glfwGetProcAddress(name);
+                            }
+                    );
+                }
+                if (!interface) {
+                    std::cerr << "Error: could not create OpenGL interface\n";
+                    std::exit(-1);
+                }
+
+#if !defined(OLD_SKIA) || OLD_SKIA == 0
                 sContext = GrDirectContexts::MakeGL(interface).release();
 
                 GrGLFramebufferInfo framebufferInfo;
@@ -1708,7 +1727,7 @@ namespace Manager {
                                           data = SkData::MakeFromFileName(fname);
                                           if (!data)
                                               throw std::runtime_error("Error: file not found");
-#ifndef OLD_SKIA
+#if !defined(OLD_SKIA) || OLD_SKIA == 0
                                           sk_sp<SkImage> image = SkImages::DeferredFromEncodedData(data);
 #else
                                           sk_sp<SkImage> image = SkImage::MakeFromEncoded(data);
@@ -2002,7 +2021,7 @@ namespace Manager {
         sk_sp<SkImage> img(rasterSurfacePtr[0]->makeImageSnapshot());
         if (!img) { return; }
 
-#ifndef OLD_SKIA
+#if !defined(OLD_SKIA) || OLD_SKIA == 0
         SkPngEncoder::Options options;
         sk_sp<SkData> png(SkPngEncoder::Encode(nullptr, img.get(), options));
 #else
@@ -2068,7 +2087,7 @@ namespace Manager {
     std::pair<const uint8_t*, size_t> GwPlot::encodeToPng(int compression_level) {
         assert (resterSurface != nullptr);
         sk_sp<SkImage> img = rasterSurface->makeImageSnapshot();
-#ifndef OLD_SKIA
+#if !defined(OLD_SKIA) || OLD_SKIA == 0
         SkPngEncoder::Options options;
         options.fZLibLevel = compression_level;
         sk_sp<SkData> png(SkPngEncoder::Encode(nullptr, img.get(), options));
@@ -2088,7 +2107,7 @@ namespace Manager {
         std::cerr << "Error: this function is not supported for Windows at the moment\n";
         return {nullptr, 0};
 #else
-    #ifndef OLD_SKIA
+    #if !defined(OLD_SKIA) || OLD_SKIA == 0
         m_encodedJpegData = SkJpegEncoder::Encode(nullptr, img.get(), options);
         return {static_cast<const uint8_t*>(m_encodedJpegData->data()), m_encodedJpegData->size()};
     #else
@@ -2117,7 +2136,7 @@ namespace Manager {
 
     void imageToPng(sk_sp<SkImage> &img, std::filesystem::path &path) {
         if (!img) { return; }
-#ifndef OLD_SKIA
+#if !defined(OLD_SKIA) || OLD_SKIA == 0
         SkPngEncoder::Options options;
         sk_sp<SkData> png(SkPngEncoder::Encode(nullptr, img.get(), options));
 #else
@@ -2137,7 +2156,7 @@ namespace Manager {
 
     void imagePngToStdOut(sk_sp<SkImage> &img) {
         if (!img) { return; }
-#ifndef OLD_SKIA
+#if !defined(OLD_SKIA) || OLD_SKIA == 0
         SkPngEncoder::Options options;
         sk_sp<SkData> png(SkPngEncoder::Encode(nullptr, img.get(), options));
 #else
@@ -2161,7 +2180,7 @@ namespace Manager {
 
     void imagePngToFile(sk_sp<SkImage> &img, std::string path) {
         if (!img) { return; }
-#ifndef OLD_SKIA
+#if !defined(OLD_SKIA) || OLD_SKIA == 0
         SkPngEncoder::Options options;
         sk_sp<SkData> png(SkPngEncoder::Encode(nullptr, img.get(), options));
 #else
